"""This module contains the GroupOperationResponse domain model."""

from .group import Group


class GroupOperationResponse(Group):
    """The API response domain model for the status of a group after the
    operation."""

    pass
